@@ -44,6 +44,18 @@ static gint gnome_db_browser_signals[GNOME_DB_BROWSER_LAST_SIGNAL] = { 0, };
 /*
  * Callbacks
  */
+static void
+add_list_row_cb (GnomeDbList *list, gint row, GnomeDbBrowser *brw)
+{
+  GnomePixmap* pixmap;
+
+  g_return_if_fail(GNOME_DB_IS_LIST(list));
+  g_return_if_fail(GNOME_DB_IS_BROWSER(brw));
+
+  pixmap = gda_ui_get_pixmap(GNOME_STOCK_MENU_BOOK_RED);
+  gnome_db_list_set_pixmap(list, row, pixmap->pixmap, pixmap->mask);
+}
+
 static void
 browse_data_cb (GtkWidget *w, gpointer data)
 {
@@ -51,9 +63,9 @@ browse_data_cb (GtkWidget *w, gpointer data)
   GnomeDbBrowser* brw = GNOME_DB_BROWSER(data);
   
   g_return_if_fail(GNOME_DB_IS_BROWSER(brw));
-  g_return_if_fail(GNOME_DB_IS_ICON_LIST(brw->object_list));
+  g_return_if_fail(GNOME_DB_IS_LIST(brw->object_list));
   
-  name = gnome_db_icon_list_get_string(GNOME_DB_ICON_LIST(brw->object_list));
+  name = gnome_db_list_get_string(GNOME_DB_LIST(brw->object_list));
   if (name)
     {
       gchar *str = 0;
@@ -139,9 +151,9 @@ extra_info_cb (GtkWidget *w, gpointer data)
   GnomeDbBrowser* brw = GNOME_DB_BROWSER(data);
   
   g_return_if_fail(GNOME_DB_IS_BROWSER(brw));
-  g_return_if_fail(GNOME_DB_IS_ICON_LIST(brw->object_list));
+  g_return_if_fail(GNOME_DB_IS_LIST(brw->object_list));
   
-  name = gnome_db_icon_list_get_string(GNOME_DB_ICON_LIST(brw->object_list));
+  name = gnome_db_list_get_string(GNOME_DB_LIST(brw->object_list));
   if (name)
     {
       Gda_Recordset* recset;
@@ -198,14 +210,14 @@ extra_info_cb (GtkWidget *w, gpointer data)
 }
 
 static void
-select_object_cb (GnomeDbIconList *icon_list, GnomeDbBrowser *brw)
+select_object_cb (GnomeDbList *icon_list, GnomeDbBrowser *brw)
 {
   gchar *name = 0;
   
-  g_return_if_fail(GNOME_DB_IS_ICON_LIST(icon_list));
+  g_return_if_fail(GNOME_DB_IS_LIST(icon_list));
   g_return_if_fail(GNOME_DB_IS_BROWSER(brw));
   
-  name = gnome_db_icon_list_get_string(icon_list);
+  name = gnome_db_list_get_string(icon_list);
   if (name)
     {
       Gda_Recordset *recset = 0;
@@ -253,7 +265,7 @@ show_aggrs_cb (GtkWidget *w, gpointer data)
                                       GDA_Connection_no_CONSTRAINT, 0);
   if (recset != 0)
     {
-      gnome_db_icon_list_set_recordset(GNOME_DB_ICON_LIST(brw->object_list), recset, 0);
+      gnome_db_list_set_recordset(GNOME_DB_LIST(brw->object_list), recset, 0);
     }
 }
 
@@ -279,7 +291,7 @@ show_tables_cb (GtkWidget *w, gpointer data)
                                       GDA_Connection_no_CONSTRAINT, 0);
   if (recset != 0)
     {
-      gnome_db_icon_list_set_recordset(GNOME_DB_ICON_LIST(brw->object_list), recset, 0);
+      gnome_db_list_set_recordset(GNOME_DB_LIST(brw->object_list), recset, 0);
     }
 }
 
@@ -305,7 +317,7 @@ show_procs_cb (GtkWidget *w, gpointer data)
                                       GDA_Connection_no_CONSTRAINT, 0);
   if (recset != 0)
     {
-      gnome_db_icon_list_set_recordset(GNOME_DB_ICON_LIST(brw->object_list), recset, 0);
+      gnome_db_list_set_recordset(GNOME_DB_LIST(brw->object_list), recset, 0);
     }
 }
 
@@ -331,7 +343,7 @@ show_types_cb (GtkWidget *w, gpointer data)
                                       GDA_Connection_no_CONSTRAINT, 0);
   if (recset != 0)
     {
-      gnome_db_icon_list_set_recordset(GNOME_DB_ICON_LIST(brw->object_list), recset, 0);
+      gnome_db_list_set_recordset(GNOME_DB_LIST(brw->object_list), recset, 0);
     }
 }
 
@@ -358,7 +370,7 @@ show_views_cb (GtkWidget *w, gpointer data)
                                       
   if (recset != 0)
     {
-      gnome_db_icon_list_set_recordset(GNOME_DB_ICON_LIST(brw->object_list), recset, 0);
+      gnome_db_list_set_recordset(GNOME_DB_LIST(brw->object_list), recset, 0);
     }
 }
 
@@ -392,21 +404,25 @@ gnome_db_browser_init (GnomeDbBrowser *brw)
   
   frame = gda_ui_new_frame_widget(NULL);
   gtk_box_pack_start(GTK_BOX(brw), frame, 1, 1, 0);
-  table = gtk_table_new(5, 4, FALSE);
+  table = gtk_table_new(6, 4, FALSE);
   gtk_container_add(GTK_CONTAINER(frame), table);
   gtk_widget_show(table);
   
-  brw->object_list = gnome_db_icon_list_new(0, 0);
+  brw->object_list = gnome_db_list_new(0, 0);
+  gtk_signal_connect(GTK_OBJECT(brw->object_list),
+		     "add_row",
+		     GTK_SIGNAL_FUNC(add_list_row_cb),
+		     (gpointer) brw);
   gtk_signal_connect(GTK_OBJECT(brw->object_list), "select_row",
                      GTK_SIGNAL_FUNC(select_object_cb), (gpointer) brw);
   gtk_widget_show(brw->object_list);
-  gtk_table_attach(GTK_TABLE(table), brw->object_list, 0, 1, 0, 5,
+  gtk_table_attach(GTK_TABLE(table), brw->object_list, 0, 3, 0, 5,
                    GTK_FILL | GTK_EXPAND | GTK_SHRINK,
                    GTK_FILL,
                    3, 3);
 
   brw->object_description = gda_ui_new_grid_widget(NULL);
-  gtk_table_attach(GTK_TABLE(table), brw->object_description, 1, 4, 1, 4,
+  gtk_table_attach(GTK_TABLE(table), brw->object_description, 3, 6, 1, 4,
                    GTK_FILL | GTK_EXPAND | GTK_SHRINK,
                    GTK_FILL | GTK_EXPAND | GTK_SHRINK,
                    3, 3);
@@ -451,13 +467,13 @@ gnome_db_browser_init (GnomeDbBrowser *brw)
   gtk_widget_show(brw->aggrs_button);
   gtk_box_pack_start(GTK_BOX(box), brw->aggrs_button, 0, 0, 0);
   
-  gtk_table_attach(GTK_TABLE(table), box, 1, 4, 0, 1, GTK_FILL, GTK_FILL, 1, 1);
+  gtk_table_attach(GTK_TABLE(table), box, 3, 6, 0, 1, GTK_FILL, GTK_FILL, 1, 1);
   gtk_widget_show(box);
   
   /* create button bar */
   box = gtk_hbox_new(TRUE, 0);
   gtk_widget_show(box);
-  gtk_table_attach(GTK_TABLE(table), box, 1, 4, 4, 5, GTK_FILL, GTK_FILL, 1, 1);
+  gtk_table_attach(GTK_TABLE(table), box, 3, 6, 4, 5, GTK_FILL, GTK_FILL, 1, 1);
                    
   button = gnome_pixmap_button(gnome_stock_new_with_icon(GNOME_STOCK_MENU_PROP),
                                _("Data"));
@@ -597,7 +613,7 @@ gnome_db_browser_clear (GnomeDbBrowser *brw)
 {
   g_return_if_fail(GNOME_DB_IS_BROWSER(brw));
   
-  gnome_db_icon_list_clear(GNOME_DB_ICON_LIST(brw->object_list));
+  gnome_db_list_clear(GNOME_DB_LIST(brw->object_list));
   gnome_db_grid_set_recordset(GNOME_DB_GRID(brw->object_description), 0);
 }
 
