@@ -116,11 +116,11 @@ gnome_db_list_class_init (GnomeDbListClass *klass)
            gtk_signal_new("select_row", GTK_RUN_LAST, object_class->type,
                           GTK_SIGNAL_OFFSET(GnomeDbListClass, select_row),
                           gtk_signal_default_marshaller,
-                          GTK_TYPE_NONE, 1, GTK_TYPE_STRING);
+                          GTK_TYPE_NONE, 0);
   gnome_db_list_signals[GNOME_DB_LIST_ADD_ROW] =
            gtk_signal_new("add_row", GTK_RUN_LAST, object_class->type,
                           GTK_SIGNAL_OFFSET(GnomeDbListClass, add_row),
-                          gtk_signal_default_marshaller,
+                          gtk_marshal_NONE__INT,
                           GTK_TYPE_NONE, 1, GTK_TYPE_INT);
   gtk_object_class_add_signals(object_class, gnome_db_list_signals,
                                GNOME_DB_LIST_LAST_SIGNAL);
@@ -315,7 +315,7 @@ gnome_db_list_set_recordset (GnomeDbList *dblist, Gda_Recordset *recset, gint po
   dblist->total_rows = 0;
   dblist->col = pos;
 
-  dblist->timeout_handle = gtk_timeout_add(150,
+  dblist->timeout_handle = gtk_timeout_add(15,
                                            (GtkFunction) timeout_callback,
                                            (gpointer) dblist);
 }
