@@ -16,10 +16,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "gnome-db-login-dlg.h"
-#include "gnome-db-error-dlg.h"
-#include "gda-error.h"
-#include "gda-server.h"
+#include "gda-ui.h"
 
 enum
 {
