@@ -28,7 +28,7 @@
 #include <gda-recordset.h>
 #include <gda-field.h>
 #include <gda-error.h>
-#include <gda-xml.h>
 #include <gda-batch.h>
+#include <gda-report.h>
 
 #endif
