@@ -241,7 +241,11 @@ get_corba_connection (Gda_Connection* cnc)
   factory = g_hash_table_lookup(factories, cnc->provider);
   if (!factory)
     {
+#if USING_OAF
+      factory = oaf_activate_from_id(cnc->provider, 0, NULL, &ev);
+#else
       factory = goad_server_activate_with_id(NULL, cnc->provider, 0, NULL);
+#endif
       g_hash_table_insert(factories, cnc->provider, factory);
     }
   CORBA_exception_init(&ev);
@@ -1019,7 +1023,7 @@ glong
 gda_connection_get_connect_timeout (Gda_Connection *cnc)
 {
   CORBA_Environment ev;
-  glong ret;
+  glong             ret;
   
   g_return_val_if_fail(IS_GDA_CONNECTION(cnc), -1);
   
@@ -1070,7 +1074,13 @@ gda_connection_set_cursor_location (Gda_Connection *cnc, GDA_CursorLocation curs
 gchar *
 gda_connection_get_version (Gda_Connection *cnc)
 {
+  CORBA_char*       version;
+  CORBA_Environment ev;
+
   g_return_val_if_fail(IS_GDA_CONNECTION(cnc), 0);
-  g_error("%s: not implemented", __PRETTY_FUNCTION__);
-  return (0);
+
+  CORBA_exception_init(&ev);
+  version = GDA_Connection__get_version(cnc->connection, &ev);
+  if (gda_connection_corba_exception(cnc, &ev) == 0) return version;
+  return NULL;
 }
