@@ -20,13 +20,6 @@
 #ifndef __gda_connection_h__
 #define __gda_connection_h__ 1
 
-#include <glib.h>
-#include <orb/orbit.h>
-#include <stdarg.h>
-#include <gnome.h>
-
-#include <gda.h>
-
 /* Data Structures and Prototypes for the Gnome DB Access Client
  * Library
  */
@@ -35,9 +28,6 @@ typedef struct _Gda_ConnectionClass  Gda_ConnectionClass;
 
 #include <gda-recordset.h>
 #include <gda-error.h>
-#include <gda-field.h>
-#include <gda-server.h>
-#include <gda-batch.h>
 
 /*
  * The connection object. The base of all acceess to data sources.
@@ -113,6 +103,7 @@ void               gda_connection_add_errorlist       (Gda_Connection* cnc, GLis
 #define            gda_connection_is_open(cnc)        ((cnc) ? GDA_CONNECTION(cnc)->is_open : FALSE)
 #define            gda_connection_get_dsn(cnc)        ((cnc) ? GDA_CONNECTION(cnc)->database : 0)
 #define            gda_connection_get_user(cnc)       ((cnc) ? GDA_CONNECTION(cnc)->user : 0)
+#define            gda_connection_get_password(cnc)   ((cnc) ? GDA_CONNECTION(cnc)->passwd : 0)
 
 glong              gda_connection_get_flags           (Gda_Connection* cnc);
 void               gda_connection_set_flags           (Gda_Connection* cnc, glong flags);
