@@ -787,7 +787,14 @@ gda_recordset_open (Gda_Recordset* rs,
       return -1;
     }
 
-  rs->field_attributes = GDA_Recordset_describe(rs->corba_rs, &ev);
+  if (CORBA_Object_is_nil(rs->corba_rs, &ev))
+    {
+      error_list = gda_errors_from_exception(&ev);
+      if (error_list) gda_connection_add_errorlist(rs->cnc, error_list);
+      rs->field_attributes = NULL;
+      return -1;
+    }
+  else rs->field_attributes = GDA_Recordset_describe(rs->corba_rs, &ev);
   error_list = gda_errors_from_exception(&ev);
   if (error_list)
     {
