@@ -28,5 +28,7 @@
 #include <gda-log.h>
 #include <gda-config.h>
 #include <gda-thread.h>
+#include <gda-xml-file.h>
+#include <gda-xml-database.h>
  
 #endif
