@@ -405,9 +405,8 @@ gnome_db_control_new (const gchar *id, GnomeDbControlFunc func)
   control->create_widget_cb = func;
 
   /* create factory */
-  factory_id = g_strdup_printf("control-factory:%s", id);
-  control->factory = gnome_db_factory_new(factory_id, control_factory, (gpointer) control);
-  g_free((gpointer) factory_id);
+  control->factory = gnome_db_factory_new(id, control_factory, (gpointer) control);
+
   if (!control->factory)
     {
       g_warning(_("Could not register control factory"));
