@@ -18,7 +18,8 @@
  
 #include "gda-builder.h"
 
-static GtkWidget* l_LoginDialog = 0;
+static GtkWidget* l_LoginDialog = NULL;
+static GtkWidget* l_BrowserTab = NULL;
 
 /*
  * Callbacks
@@ -39,19 +40,22 @@ login_cb (Gda_Connection *cnc)
     {
       gchar *dsn;
       GnomeDbLogin *login = GNOME_DB_LOGIN(GNOME_DB_LOGINDLG(l_LoginDialog)->login);
-      if (login != 0)
+      if (login)
         dsn = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(login->gda_dbname)->entry));
-      else dsn = 0;
+      else dsn = NULL;
       
       /* close previous connection, if any */
-      if (glb_dbconn != 0)
+      if (IS_GDA_CONNECTION(glb_dbconn))
         {
           gda_connection_free(glb_dbconn);
         }
       glb_dbconn = cnc;
 
       gnome_dialog_close(GNOME_DIALOG(l_LoginDialog));
-      l_LoginDialog = 0;
+      l_LoginDialog = NULL;
+
+      gnome_db_container_set_status(GNOME_DB_CONTAINER(glb_Container),
+				    _("Connected to %s"), dsn);
     }
 }
 
@@ -98,8 +102,52 @@ builder_database_disconnect (GtkWidget *w, gpointer data)
 {
   if (glb_dbconn != 0)
     {
+      /* close browser tab */
+      if (GNOME_DB_IS_BROWSER(l_BrowserTab))
+	{
+	  gtk_notebook_remove_page(GTK_NOTEBOOK(glb_Notebook),
+				   gtk_notebook_page_num(GTK_NOTEBOOK(glb_Notebook),
+							 l_BrowserTab));
+	}
+      l_BrowserTab = NULL;
+
+      /* close connection */
       if (gda_connection_is_open(glb_dbconn)) gda_connection_close(glb_dbconn);
       gda_connection_free(glb_dbconn);
-      glb_dbconn = 0;
+      glb_dbconn = NULL;
+      gnome_db_container_set_status(GNOME_DB_CONTAINER(glb_Container),
+				    _("Disconnected from database"));
     }
-}
\ No newline at end of file
+}
+
+void
+builder_database_browse (void)
+{
+  if (gda_connection_is_open(glb_dbconn))
+    {
+      /* create the browser tab */
+      if (!GTK_IS_WIDGET(l_BrowserTab))
+	{
+	  l_BrowserTab = gnome_db_browser_new(glb_dbconn);
+	  gtk_widget_show(l_BrowserTab);
+	  gtk_notebook_append_page(GTK_NOTEBOOK(glb_Notebook),
+				   l_BrowserTab,
+				   gtk_label_new(_("Database Browser")));
+	}
+      else gnome_db_browser_set_connection(GNOME_DB_BROWSER(l_BrowserTab), glb_dbconn);
+
+      gtk_notebook_set_page(GTK_NOTEBOOK(glb_Notebook),
+			    gtk_notebook_page_num(GTK_NOTEBOOK(glb_Notebook),
+						  l_BrowserTab));
+    }
+  else gnome_db_container_set_status(GNOME_DB_CONTAINER(glb_Container),
+				     _("There are no open connections"));
+}
+
+void
+builder_database_import_objects (GtkWidget *w, gpointer data)
+{
+  if (gda_connection_is_open(glb_dbconn))
+    {
+    }
+}
