@@ -17,6 +17,7 @@
  */
 
 #include "gda-fe.h"
+#include <stdio.h>
 
 static void activate_export_cb   (GtkWidget *w, gpointer data);
 static void activate_import_cb   (GtkWidget *w, gpointer data);
@@ -122,11 +123,16 @@ fill_feature_list (Gda_Connection *cnc, GtkCList *clist)
     GDA_Connection_Feature feature;
   } features[] =
   {
+    { N_("Foreign keys"), GDA_Connection_FEATURE_FOREIGN_KEYS },
     { N_("Object Identifiers"), GDA_Connection_FEATURE_OBJECT_ID },
     { N_("Object Inheritance"), GDA_Connection_FEATURE_INHERITANCE },
     { N_("Sequences"), GDA_Connection_FEATURE_SEQUENCES },
+    { N_("SQL (Standard)"), GDA_Connection_FEATURE_SQL },
+    { N_("SQL Sub-Selects"), GDA_Connection_FEATURE_SQL_SUBSELECT },
     { N_("Stored Procedures"), GDA_Connection_FEATURE_PROCS },
     { N_("Transactions"), GDA_Connection_FEATURE_TRANSACTIONS },
+    { N_("Triggers"), GDA_Connection_FEATURE_TRIGGERS },
+    { N_("Views"), GDA_Connection_FEATURE_VIEWS },
     { N_("XML Queries"), GDA_Connection_FEATURE_XML_QUERIES }
   };
   GtkWidget* on_pixmap;
@@ -418,6 +424,34 @@ open_sql_cb (GtkWidget *w, gpointer data)
       gchar* filename = gda_ui_select_file(_("Select file"));
       if (filename)
 	{
+	  FILE* fp;
+
+	  fp = fopen(filename, "r");
+	  if (fp)
+	    {
+	      gchar  buffer[513];
+
+	      /* read file contents */
+	      gtk_editable_delete_text(GTK_EDITABLE(cnc_data->cmd_area),
+				       0,
+				       gtk_text_get_length(GTK_TEXT(cnc_data->cmd_area)));
+	      while (!feof(fp))
+		{
+		  memset(buffer, '\0', sizeof(buffer));
+		  fread((const void *) buffer, sizeof(buffer) - 1, 1, fp);
+		  if (ferror(fp))
+		    {
+		      gda_ui_show_error(_("Error reading from file\n'%s'"), filename);
+		      break;
+		    }
+		  buffer[sizeof(buffer) - 1] = '\0';
+		  gtk_text_insert(GTK_TEXT(cnc_data->cmd_area), NULL, NULL, NULL,
+				  buffer, sizeof(buffer) - 1);
+		  
+		}
+	      fclose(fp);
+	    }
+	  else gda_ui_show_error(_("Could not open file\n'%s'"), filename);
 	  g_free((gpointer) filename);
 	}
     }
@@ -470,6 +504,23 @@ save_sql_cb (GtkWidget *w, gpointer data)
       gchar* filename = gda_ui_select_file(_("Select file"));
       if (filename)
 	{
+	  gchar* txt;
+
+	  txt = gtk_editable_get_chars(GTK_EDITABLE(cnc_data->cmd_area),
+				       0,
+				       gtk_text_get_length(GTK_TEXT(cnc_data->cmd_area)));
+	  if (txt)
+	    {
+	      FILE* fp = fopen(filename, "w");
+	      if (fp)
+		{
+		  fwrite((void *) txt, strlen(txt), 1, fp);
+		  if (ferror(fp))
+		    gda_ui_show_error(_("Error writing to file\n'%s'"), filename);
+		  fclose(fp);
+		}
+	      else gda_ui_show_error(_("Could not open file\n'%s'"), filename);
+	    }
 	  g_free((gpointer) filename);
 	}
     }
@@ -541,6 +592,7 @@ void
 fe_connection_open (const gchar *str, Gda_Connection *cnc)
 {
   connection_data_t* cnc_data;
+  gchar*             label;
 
   g_return_if_fail(IS_GDA_CONNECTION(cnc));
   g_return_if_fail(gda_connection_is_open(cnc));
@@ -556,7 +608,9 @@ fe_connection_open (const gchar *str, Gda_Connection *cnc)
   init_sql_window(cnc_data);
 
   cnc_data->gda_name = g_strdup(str);
-  fe_workarea_add_tab(cnc_data->gda_name, cnc_data->widget, cnc_toolbox);
+  label = g_strdup_printf("%s@%s", gda_connection_get_user(cnc), cnc_data->gda_name);
+  fe_workarea_add_tab(label, cnc_data->widget, cnc_toolbox);
+  g_free((gpointer) label);
   connections = g_list_append(connections, (gpointer) cnc_data);
 }
 
@@ -780,7 +834,7 @@ fe_connection_view_properties (void)
       frame = gda_ui_new_frame_widget(_("Properties"));
       gtk_container_set_border_width(GTK_CONTAINER(frame), 3);
       gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), frame, 0, 0, 0);
-      table = gda_ui_new_table_widget(3, 6, 0);
+      table = gda_ui_new_table_widget(3, 7, 0);
       gtk_container_add(GTK_CONTAINER(frame), table);
 
       label = gda_ui_new_label_widget(_("GDA Name"));
@@ -804,15 +858,15 @@ fe_connection_view_properties (void)
       label = gda_ui_new_label_widget(_("Command Timeout"));
       gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4, GTK_FILL, GTK_FILL, 3, 3);
       entry = gda_ui_new_entry_widget(0, FALSE);
-      //sprintf(txt, "%ld", gda_connection_get_cmd_timeout(cnc_data->cnc));
-      //gtk_entry_set_text(GTK_ENTRY(entry), txt);
+      sprintf(txt, "%ld", gda_connection_get_cmd_timeout(cnc_data->cnc));
+      gtk_entry_set_text(GTK_ENTRY(entry), txt);
       gtk_table_attach(GTK_TABLE(table), entry, 1, 2, 3, 4, GTK_FILL, GTK_FILL, 3, 3);
 
       label = gda_ui_new_label_widget(_("Connect Timeout"));
       gtk_table_attach(GTK_TABLE(table), label, 0, 1, 4, 5, GTK_FILL, GTK_FILL, 3, 3);
       entry = gda_ui_new_entry_widget(0, FALSE);
-      //sprintf(txt, "%ld", gda_connection_get_connect_timeout(cnc_data->cnc));
-      //gtk_entry_set_text(GTK_ENTRY(entry), txt);
+      sprintf(txt, "%ld", gda_connection_get_connect_timeout(cnc_data->cnc));
+      gtk_entry_set_text(GTK_ENTRY(entry), txt);
       gtk_table_attach(GTK_TABLE(table), entry, 1, 2, 4, 5, GTK_FILL, GTK_FILL, 3, 3);
 
       label = gda_ui_new_label_widget(_("Trace File"));
@@ -822,6 +876,12 @@ fe_connection_view_properties (void)
       button = gda_ui_new_button_widget_with_pixmap(_("View"), GNOME_STOCK_MENU_PROP);
       gtk_table_attach(GTK_TABLE(table), button, 2, 3, 5, 6, GTK_SHRINK, GTK_SHRINK, 3, 3);
 
+      label = gda_ui_new_label_widget(_("Version"));
+      gtk_table_attach(GTK_TABLE(table), label, 0, 1, 6, 7, GTK_FILL, GTK_FILL, 3, 3);
+      entry = gda_ui_new_entry_widget(0, FALSE);
+      gtk_entry_set_text(GTK_ENTRY(entry), gda_connection_get_version(cnc_data->cnc));
+      gtk_table_attach(GTK_TABLE(table), entry, 1, 2, 6, 7, GTK_FILL, GTK_FILL, 3, 3);
+
       frame2 = gda_ui_new_frame_widget(_("Provider Features"));
       gtk_container_set_border_width(GTK_CONTAINER(frame2), 3);
       gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), frame2, 1, 1, 0);
