@@ -19,17 +19,17 @@
 
 #include "gda-mgr.h"
 
-static void add_dsn_cb        (GtkWidget *widget, gpointer data);
-static void browse_dsn_cb     (GtkWidget *widget, gpointer data);
-static void config_dsn_cb     (GtkWidget *widget, gpointer data);
-static void edit_dsn_cb       (GtkWidget *widget, gpointer data);
-static void remove_dsn_cb     (GtkWidget *widget, gpointer data);
-static void view_providers_cb (GtkWidget *widget, gpointer data);
+static void add_dsn_cb           (GtkWidget *widget, gpointer data);
+static void browse_dsn_cb        (GtkWidget *widget, gpointer data);
+static void config_dsn_cb        (GtkWidget *widget, gpointer data);
+static void edit_dsn_cb          (GtkWidget *widget, gpointer data);
+static void remove_dsn_cb        (GtkWidget *widget, gpointer data);
+static void view_log_entry_cb    (GtkWidget *widget, gpointer data);
 
 static void view_provider_log_cb (GtkWidget *w, gpointer data);
 
-static GtkWidget* l_ProviderList = 0;
-static GtkWidget* l_DsnList = 0;
+static GtkWidget* l_gda_tab = NULL;
+static GtkWidget* l_DsnList = NULL;
 
 static GnomeUIInfo gdatoolbar[] =
 {
@@ -48,27 +48,6 @@ static GnomeUIInfo gdatoolbar[] =
   { GNOME_APP_UI_ITEM, N_("Browse"), N_("Browse selected data source"),
     browse_dsn_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_PROP, 0, 0, NULL },
-  GNOMEUIINFO_SEPARATOR,
-  { GNOME_APP_UI_ITEM, N_("Providers"), N_("View GDA providers"),
-    view_providers_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-    GNOME_STOCK_MENU_HOME, 0, 0, NULL },
-  GNOMEUIINFO_END
-};
-static GnomeUIInfo providerstoolbar[] =
-{
-  { GNOME_APP_UI_ITEM, N_("Logs"), N_("View provider log"),
-    view_provider_log_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-    GNOME_STOCK_MENU_MAIL, 0, 0, NULL },
-  GNOMEUIINFO_SEPARATOR,
-  { GNOME_APP_UI_ITEM, N_("New"), N_("Install a new GDA provider"),
-    NULL, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-    GNOME_STOCK_MENU_NEW, 0, 0, NULL },
-  { GNOME_APP_UI_ITEM, N_("Edit"), N_("Edit selected provider"),
-    NULL, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-    GNOME_STOCK_MENU_PREF, 0, 0, NULL },
-  { GNOME_APP_UI_ITEM, N_("Remove"), N_("Remove selected provider"),
-    NULL, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-    GNOME_STOCK_MENU_TRASH, 0, 0, NULL },
   GNOMEUIINFO_END
 };
 
@@ -118,7 +97,7 @@ fill_dsn_list (GtkCList *clist)
           row[1] = GDA_DSN_DESCRIPTION(dsn);
           row[2] = empty_string;
 
-          gtk_clist_append(clist, (const gchar **) row);
+          gtk_clist_append(GTK_CLIST(clist), (const gchar **) row);
           if (GDA_DSN_IS_GLOBAL(dsn))
             {
               gtk_clist_set_pixmap(clist, cnt, 2,
@@ -139,44 +118,6 @@ fill_dsn_list (GtkCList *clist)
   gtk_clist_thaw(clist);
 }
 
-static void
-fill_provider_list (GtkCList *clist)
-{
-  gchar* empty_string = "";
-  gchar* row[4];
-  GList* server_list;
-  GList* node;
-
-  g_return_if_fail(GTK_IS_CLIST(clist));
-
-  gtk_clist_freeze(clist);
-  server_list = gda_server_list();
-  node = g_list_first(server_list);
-  while (node)
-    {
-      gchar* type_exe = "exe";
-      gchar* type_lib = "shlib";
-      gchar* type_relay = "relay";
-
-      Gda_Server* server = (Gda_Server *) node->data;
-      if (server)
-        {
-          row[0] = GDA_SERVER_NAME(server);
-          if (GDA_SERVER_GOAD_TYPE(server) == GOAD_SERVER_EXE) row[1] = type_exe;
-          else if (GDA_SERVER_GOAD_TYPE(server) == GOAD_SERVER_SHLIB) row[1] = type_lib;
-	  else if (GDA_SERVER_GOAD_TYPE(server) == GOAD_SERVER_RELAY) row[1] = type_relay;
-          else row[1] = empty_string;
-          row[2] = GDA_SERVER_COMMENT(server);
-          row[3] = GDA_SERVER_LOCATION(server);
-
-          gtk_clist_append(clist, (const gchar **) row);
-        }
-      node = g_list_next(node);
-    }
-  gda_server_free_list(server_list);
-  gtk_clist_thaw(clist);
-}
-
 static const gchar *
 get_current_dsn (void)
 {
@@ -218,7 +159,8 @@ manage_dsn (gchar *name)
   btn = gnome_dialog_run(GNOME_DIALOG(dialog));
   if (btn == 0) /* 'OK' button */
     {
-      gnome_db_dsn_config_save(dsnconf);
+      gnome_db_dsn_config_save(GNOME_DB_DSN_CONFIG(dsnconf));
+      fill_dsn_list(GTK_CLIST(l_DsnList));
     }
   gnome_dialog_close(GNOME_DIALOG(dialog));
 }
@@ -336,6 +278,7 @@ config_dsn_cb (GtkWidget *widget, gpointer data)
       GtkWidget* entry;
       GtkWidget* user_entry;
       GtkWidget* pwd_entry;
+      GtkWidget* db_button;
       GtkWidget* users_button;
       GtkWidget* access_button;
       GtkWidget* all_button;
@@ -372,23 +315,27 @@ config_dsn_cb (GtkWidget *widget, gpointer data)
 		       GTK_FILL | GTK_SHRINK | GTK_EXPAND,
 		       GTK_FILL | GTK_SHRINK | GTK_EXPAND,
 		       3, 3);
-      table = gda_ui_new_table_widget(1, 4, FALSE);
+      table = gda_ui_new_table_widget(1, 5, FALSE);
       gtk_container_add(GTK_CONTAINER(frame), table);
 
-      users_button = gda_ui_new_radio_button_widget(_("Users"), NULL);
-      gtk_table_attach(GTK_TABLE(table), users_button, 0, 1, 0, 1,
+      db_button = gda_ui_new_radio_button_widget(_("Database"), NULL);
+      gtk_table_attach(GTK_TABLE(table), db_button, 0, 1, 0, 1,
+		       GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL, 1, 1);
+      users_button = gda_ui_new_radio_button_widget(_("Users"),
+                                                    GTK_RADIO_BUTTON(db_button));
+      gtk_table_attach(GTK_TABLE(table), users_button, 0, 1, 1, 2,
 		       GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL, 1, 1);
       access_button = gda_ui_new_radio_button_widget(_("User access rights"),
 						     GTK_RADIO_BUTTON(users_button));
-      gtk_table_attach(GTK_TABLE(table), access_button, 0, 1, 1, 2,
+      gtk_table_attach(GTK_TABLE(table), access_button, 0, 1, 2, 3,
 		       GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL, 1, 1);
       sep = gtk_hseparator_new();
       gtk_widget_show(sep);
-      gtk_table_attach(GTK_TABLE(table), sep, 0, 1, 2, 3,
+      gtk_table_attach(GTK_TABLE(table), sep, 0, 1, 3, 4,
 		       GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL, 1, 1);
       all_button = gda_ui_new_radio_button_widget(_("All"),
 						  GTK_RADIO_BUTTON(users_button));
-      gtk_table_attach(GTK_TABLE(table), all_button, 0, 1, 3, 4,
+      gtk_table_attach(GTK_TABLE(table), all_button, 0, 1, 4, 5,
 		       GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL, 1, 1);
 
       if (!gnome_dialog_run(GNOME_DIALOG(dialog)))
@@ -404,7 +351,9 @@ config_dsn_cb (GtkWidget *widget, gpointer data)
 	      username = gtk_entry_get_text(GTK_ENTRY(user_entry));
 	      password = gtk_entry_get_text(GTK_ENTRY(pwd_entry));
 
-	      if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(users_button)))
+              if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(db_button)))
+                module = g_strdup_printf("control:%s-db", GDA_DSN_PROVIDER(dsn));
+	      else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(users_button)))
 		module = g_strdup_printf("control:%s-users-list", GDA_DSN_PROVIDER(dsn));
 	      else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(access_button)))
 		module = g_strdup_printf("control:%s-users-ac", GDA_DSN_PROVIDER(dsn));
@@ -448,106 +397,47 @@ remove_dsn_cb (GtkWidget *widget, gpointer data)
     }
 }
 
-static void
-view_provider_log_cb (GtkWidget *widget, gpointer data)
-{
-  GList* selected;
-
-  g_return_if_fail(GTK_IS_CLIST(data));
-
-  selected = GTK_CLIST(data)->selection;
-  if (selected)
-    {
-      gchar* provider = 0;
-
-      guint row = GPOINTER_TO_UINT(selected->data);
-      gtk_clist_get_text(GTK_CLIST(data), row, 0, &provider);
-      if (provider)
-        {
-          gchar* filename = g_strdup_printf("/tmp/%s-srv.log", provider);
-          gda_ui_show_file(filename);
-          g_free((gpointer) filename);
-        }
-    }
-}
-
-static void
-view_providers_cb (GtkWidget *widget, gpointer data)
-{
-  GtkWidget* dialog;
-  GtkWidget* table;
-  GtkWidget* scroll;
-  GtkWidget* clist;
-  GtkWidget* frame;
-  GtkWidget* toolbar;
-  gchar*     col_titles[4] = { N_("Name"), N_("Type"), N_("Comments"), N_("Location") };
-
-  /* create dialog */
-  dialog = gnome_dialog_new(_("GDA Providers"),
-			    GNOME_STOCK_BUTTON_CLOSE,
-			    NULL);
-  gtk_widget_set_usize(dialog, 500, 350);
-  table = gda_ui_new_table_widget(4, 3, FALSE);
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), table, 1, 1, 0);
-  scroll = gda_ui_new_scrolled_window_widget();
-  gtk_table_attach(GTK_TABLE(table), scroll, 0, 3, 0, 3,
-		   GTK_SHRINK | GTK_FILL | GTK_EXPAND,
-		   GTK_SHRINK | GTK_FILL | GTK_EXPAND,
-		   3, 3);
-  clist = gda_ui_new_clist_widget(col_titles, 4);
-  fill_provider_list(GTK_CLIST(clist));
-  gtk_container_add(GTK_CONTAINER(scroll), clist);
-
-  toolbar = gda_ui_new_toolbar_widget(GTK_ORIENTATION_VERTICAL,
-				      GTK_TOOLBAR_BOTH,
-				      providerstoolbar,
-				      (gpointer) clist);
-  gtk_table_attach(GTK_TABLE(table), toolbar, 3, 4, 0, 3, GTK_FILL, GTK_FILL, 3, 3);
-      
-  gnome_dialog_run_and_close(GNOME_DIALOG(dialog));
-}
-
 /*
  * Public functions
  */
 void
 manager_gda_init (void)
 {
+  static gboolean initialized = FALSE;
   const gchar* dsn_titles[] = { N_("GDA Name"), N_("Description"), N_("Global") };
-  GtkWidget*   frame;
-  GtkWidget*   table;
-  GtkWidget*   table2;
   GtkWidget*   scroll;
   GtkWidget*   toolbar;
 
   g_return_if_fail(GTK_IS_NOTEBOOK(glb_Notebook));
 
-  table = gtk_table_new(2, 2, FALSE);
-  gtk_widget_show(table);
-  gtk_notebook_append_page(GTK_NOTEBOOK(glb_Notebook), table, gtk_label_new(_("GDA Configuration")));
+  if (!initialized)
+    {
+      l_gda_tab = gda_ui_new_table_widget(1, 2, FALSE);
+      gtk_notebook_append_page(GTK_NOTEBOOK(glb_Notebook), l_gda_tab, gtk_label_new(_("Data Sources")));
 
-  /* data sources frame */
-  frame = gda_ui_new_frame_widget(_("Data Sources"));
-  gtk_table_attach(GTK_TABLE(table), frame, 0, 1, 1, 2,
-                   GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-                   GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-                   3, 3);
-  table2 = gtk_table_new(1, 2, FALSE);
-  gtk_widget_show(table2);
-  gtk_container_add(GTK_CONTAINER(frame), table2);
-  scroll = gda_ui_new_scrolled_window_widget();
-  gtk_table_attach(GTK_TABLE(table2), scroll, 0, 1, 0, 1,
-                   GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-                   GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-                   3, 3);
-  l_DsnList = gda_ui_new_clist_widget(dsn_titles,
-                                      sizeof(dsn_titles) / sizeof(dsn_titles[0]));
-  gtk_container_add(GTK_CONTAINER(scroll), l_DsnList);
-  fill_dsn_list(GTK_CLIST(l_DsnList));
+      scroll = gda_ui_new_scrolled_window_widget();
+      gtk_table_attach(GTK_TABLE(l_gda_tab), scroll, 0, 1, 0, 1,
+		       GTK_FILL | GTK_EXPAND | GTK_SHRINK,
+		       GTK_FILL | GTK_EXPAND | GTK_SHRINK,
+		       3, 3);
+      l_DsnList = gda_ui_new_clist_widget(dsn_titles,
+					  sizeof(dsn_titles) / sizeof(dsn_titles[0]));
+      gtk_container_add(GTK_CONTAINER(scroll), l_DsnList);
+      fill_dsn_list(GTK_CLIST(l_DsnList));
+      
+      toolbar = gda_ui_new_toolbar_widget(GTK_ORIENTATION_VERTICAL,
+					  GTK_TOOLBAR_BOTH,
+					  gdatoolbar,
+					  NULL);
+      gtk_table_attach(GTK_TABLE(l_gda_tab), toolbar, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
+      initialized = TRUE;
+    }
+  manager_gda_activate();
+}
 
-  toolbar = gda_ui_new_toolbar_widget(GTK_ORIENTATION_VERTICAL,
-				      GTK_TOOLBAR_BOTH,
-				      gdatoolbar,
-				      NULL);
-  gtk_table_attach(GTK_TABLE(table2), toolbar, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
+void
+manager_gda_activate (void)
+{
+  gtk_notebook_set_page(GTK_NOTEBOOK(glb_Notebook),
+			gtk_notebook_page_num(GTK_NOTEBOOK(glb_Notebook), l_gda_tab));
 }
