@@ -26,10 +26,11 @@
 static guint prepare_app (void);
 
 /* global variables */
-GtkWidget*      glb_App = 0;
-GtkWidget*      glb_Notebook = 0;
-GtkWidget*      glb_StatusBar = 0;
-CORBA_ORB       glb_Orb;
+GtkWidget* glb_App = 0;
+GtkWidget* glb_Shortcut = 0;
+GtkWidget* glb_Notebook = 0;
+GtkWidget* glb_StatusBar = 0;
+CORBA_ORB  glb_Orb;
 
 /* menus */
 GnomeUIInfo filemenu[] =
@@ -63,13 +64,13 @@ GnomeUIInfo toolsmenu[] =
 };
 GnomeUIInfo helpmenu[] =
 {
-#if !defined(HAVE_BONOBO)
-  GNOMEUIINFO_HELP("gnome-db"),
-#endif
-  GNOMEUIINFO_SEPARATOR,
   { GNOME_APP_UI_ITEM, N_("About gnome-db..."), N_("About this program"),
     manager_about_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_ABOUT, 0, 0, NULL },
+  GNOMEUIINFO_SEPARATOR,
+  { GNOME_APP_UI_ITEM, N_("Submit bug report"), N_("About this program"),
+    gda_ui_submit_bug_cb, NULL, NULL, GNOME_APP_PIXMAP_NONE,
+    NULL, 0, 0, NULL },
   GNOMEUIINFO_END
 };
 GnomeUIInfo mainmenu[] =
@@ -114,7 +115,7 @@ Exception (CORBA_Environment *ev)
     }
 }
 
-gint 
+gint
 main (gint argc, gchar *argv[])
 {
   CORBA_Environment ev;
@@ -155,6 +156,7 @@ prepare_app (void)
 {
 #if defined(HAVE_BONOBO)
   BonoboUIHandlerMenuItem* list;
+  GtkWidget*               table;
 #endif
 
   glb_App = gnome_app_new("gda-mgr", "GDA Manager");
@@ -175,8 +177,29 @@ prepare_app (void)
                   
   /* set main window contents */
   gnome_app_create_toolbar(GNOME_APP(glb_App), toolbar);
+  table = gda_ui_new_table_widget(5, 1, TRUE);
+  glb_Shortcut = gda_ui_shortcut_new();
+  gda_ui_shortcut_append(glb_Shortcut,
+			 _("Data Sources"),
+			 gnome_pixmap_file("gnome-calendar.png"),
+			 manager_activate_dsn_cb,
+			 NULL);
+  gda_ui_shortcut_append(glb_Shortcut,
+			 _("Providers"),
+			 gnome_pixmap_file("gnome-util.png"),
+			 manager_activate_providers_cb,
+			 NULL);
+  gtk_table_attach(GTK_TABLE(table), glb_Shortcut, 0, 1, 0, 1,
+		   GTK_FILL | GTK_EXPAND,
+		   GTK_FILL | GTK_SHRINK | GTK_EXPAND,
+		   3, 3);
   glb_Notebook = gda_ui_new_notebook_widget();
-  gnome_app_set_contents(GNOME_APP(glb_App), glb_Notebook);
+  gtk_notebook_set_show_tabs(GTK_NOTEBOOK(glb_Notebook), FALSE);
+  gtk_table_attach(GTK_TABLE(table), glb_Notebook, 1, 5, 0, 1,
+		   GTK_FILL | GTK_SHRINK | GTK_EXPAND,
+		   GTK_FILL | GTK_SHRINK | GTK_EXPAND,
+		   3, 3);
+  gnome_app_set_contents(GNOME_APP(glb_App), table);
 
   /* create menus */
 #if defined(HAVE_BONOBO)
@@ -201,6 +224,9 @@ prepare_app (void)
 
   /* add "GDA Configuration" tab */
   manager_gda_init();
+  manager_gda_init_providers();
+
+  manager_gda_activate();
 
   return FALSE;
 }
