@@ -34,18 +34,26 @@
 /*
  * UI callbacks
  */
-extern void manager_about_cb          (GtkWidget *w, gpointer data);
-extern void manager_close_tab_cb      (GtkWidget *w, gpointer data);
-extern void manager_load_component_cb (GtkWidget *w, gpointer data);
-extern void manager_quit_cb           (GtkWidget *w, gpointer data);
-extern void manager_run_app_cb        (GtkWidget *w, const gchar *cmd);
-extern void manager_show_props_cb     (GtkWidget *w, gpointer data);
+extern void manager_about_cb              (GtkWidget *w, gpointer data);
+extern void manager_activate_dsn_cb       (GtkWidget *w, gpointer data);
+extern void manager_activate_providers_cb (GtkWidget *w, gpointer data);
+extern void manager_close_tab_cb          (GtkWidget *w, gpointer data);
+extern void manager_load_component_cb     (GtkWidget *w, gpointer data);
+extern void manager_quit_cb               (GtkWidget *w, gpointer data);
+extern void manager_run_app_cb            (GtkWidget *w, const gchar *cmd);
+extern void manager_show_props_cb         (GtkWidget *w, gpointer data);
 
 /*
  * GDA configuration
  */
-extern void manager_gda_init (void);
+extern void manager_gda_init               (void);
+extern void manager_gda_activate           (void);
+extern void manager_gda_init_providers     (void);
+extern void manager_gda_activate_providers (void);
 
+/*
+ * Application settings
+ */
 extern void manager_config_load (void);
 extern void manager_config_save (void);
 
@@ -93,6 +101,7 @@ extern MANAGER_Container* manager_container_find      (const gchar* module);
  * Global variables
  */
 extern GtkWidget*       glb_App;
+extern GtkWidget*       glb_Shortcut;
 extern GtkWidget*       glb_Notebook;
 extern GtkWidget*       glb_StatusBar;
 extern CORBA_ORB        glb_Orb;
