@@ -28,6 +28,10 @@ Gda_POSTGRES_Connection *gda_postgres_cmd_set_connection (Gda_POSTGRES_Command *
 Gda_POSTGRES_Recordset  *gda_postgres_cmd_execute (Gda_POSTGRES_Command *,
 						   Gda_POSTGRES_Error *,
 						   const GDA_CmdParameterSeq *,
+						   gulong *affected,
 						   gulong );
+Gda_POSTGRES_Recordset  *gda_postgres_cmd_execute_from_builtin (Gda_POSTGRES_Command *cmd,
+								Gda_Builtin_Result *res,
+								gulong *affected);
 
 #endif
