@@ -17,6 +17,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include "config.h"
 #define _MAIN_CONFIG_
 #include "gda-postgres-config.h"
 #undef _MAIN_CONFIG_
@@ -331,9 +332,15 @@ main (int argc, char *argv[])
   controls_list = NULL;
 
   /* register the users list control */
+#if USING_OAF
   control = 
-    GNOME_DB_CONTROL(gnome_db_control_new("gda-postgres-users-list", 
+    GNOME_DB_CONTROL(gnome_db_control_new("OAFIID:control-factory:gda-postgres-users-list:b8694bd8-fa17-4ee2-a436-7c18a82d6d33",
 					  create_users_list_widget_cb));
+#else
+  control = 
+    GNOME_DB_CONTROL(gnome_db_control_new("control-factory:gda-postgres-users-list", 
+					  create_users_list_widget_cb));
+#endif
 
   if (control)
     {
@@ -350,9 +357,15 @@ main (int argc, char *argv[])
   g_print("Control gda-postgres-user-list %p created\n", control);
 
   /* register the users access control */
+#if USING_OAF
   control = 
-    GNOME_DB_CONTROL(gnome_db_control_new("gda-postgres-users-ac", 
+    GNOME_DB_CONTROL(gnome_db_control_new("OAFIID:control-factory:gda-postgres-users-ac:5f36ac99-710f-4842-a8bb-3822ac2a2c81",
 					  create_users_ac_widget_cb));
+#else
+  control = 
+    GNOME_DB_CONTROL(gnome_db_control_new("control-factory:gda-postgres-users-ac", 
+					  create_users_ac_widget_cb));
+#endif
 
   if (control)
     {
@@ -369,9 +382,16 @@ main (int argc, char *argv[])
   g_print("Control gda-postgres-user-ac %p created\n", control);
 
   /* register the global config control */
+#if USING_OAF
   control = 
-    GNOME_DB_CONTROL(gnome_db_control_new("gda-postgres-config", 
+    GNOME_DB_CONTROL(gnome_db_control_new("OAFIID:control-factory:gda-postgres-config:3f8de37c-c887-412d-840b-caeba9954ffe",
 					  create_config_widget_cb));
+#else
+  control = 
+    GNOME_DB_CONTROL(gnome_db_control_new("control-factory:gda-postgres-config", 
+					  create_config_widget_cb));
+#endif
+
   if (control)
     {
       /* FIXME */
