@@ -18,8 +18,8 @@
 #include <stdio.h>
 
 #include <libgnorba/gnorba.h>
-#include "gda-connection.h"
-#include "gda-command.h"
+#include <gda-client.h>
+
 gchar* provider = 0;
 gchar* database = 0;
 gchar* username = 0;
