@@ -17,9 +17,7 @@
  */
 #include <stdio.h>
 #include <libgnorba/gnorba.h>
-#include "gda.h"
-#include "gda-connection.h"
-#include "gda-command.h"
+#include <gda-client.h>
 
 gchar* provider = 0;
 gchar* database = 0;
