@@ -19,12 +19,7 @@
 
 
 #include <libgnorba/gnorba.h>
-#include "gda.h"
-#include "gda-connection.h"
-#include "gda-command.h"
-#include "gda-error.h"
-#include "gnome-db-grid.h"
-
+#include <gda-ui.h>
 
 static void create_main_dialog (void);
 
