@@ -3,4 +3,4 @@
 #include <stdio.h>
 #include <libgnorba/gnorba.h>
 #include <gda.h>
-#include <gda-connection.h>
+#include <gda-client.h>
