@@ -1,5 +1,3 @@
-#include <gda.h>
-#include <gda-connection.h>
 #include <gda-ui.h>
 
 /* Define constants that relate to the position
